# -*- coding: utf-8 -*-

import gettext

VERSION = "3.2.0"
PACKAGE = "gedit-latex"
PACKAGE_STRING = "gedit-latex 3.2.0"
GETTEXT_PACKAGE = "gedit-latex"
GL_LOCALEDIR = "/home/jaliste/install/share/locale"

try:
    gettext.bindtextdomain(GETTEXT_PACKAGE, GL_LOCALEDIR)
    _ = lambda s: gettext.dgettext(GETTEXT_PACKAGE, s);
except:
    _ = lambda s: s
